@@ -1,18 +1,7 @@
-# /*
-#  * Adapted from ROTS Bioconductor (3.19, 2024) file bootstrapSamples.R
-#  * Copyright on original version by: F. Seyednasrollah, T. Suomi,
-#  * L.L. Elo (2024)
-#  * Copyright on modifications (C) 2024-2025 A. Youssef
-#  * Modifications: LimROTS::bootstrapS simplifies ROTS::bootstrapS 
-#  * to unpaired group-wise resampling and returning 
-#  * row names instead of indices.
-#  */
-#
 #' Generate Bootstrap Samples
 #'
 #' This function generates bootstrap samples from the input metadata. It samples
-#'  with replacement within each group defined in the metadata, and optionally
-#'  adjusts for paired groups.
+#'  with replacement within each group defined in the metadata.
 #'
 #' @param niter Integer. The number of bootstrap samples to generate.
 #' @param meta.info Data frame. Metadata containing sample information, where
@@ -31,16 +20,23 @@
 #'
 #'
 bootstrapS <- function(niter, meta.info, group.name) {
-    groups <- meta.info[, group.name]
-    bootsamples <- matrix(nrow = niter, ncol = length(groups))
-    for (i in seq_len(niter)) {
-        for (g in unique(groups)) {
-            g.names <- row.names(meta.info)[which(groups == g)]
-            bootsamples[i, which(groups == g)] <-
-                sample(g.names, length(g.names), replace = TRUE)
-        }
-    }
-    return(bootsamples)
+  group_labels <- meta.info[[group.name]]
+  ids <- rownames(meta.info)
+  index_map <- split(seq_along(ids), group_labels)
+  out <- matrix(NA_character_, nrow = niter, ncol = length(ids))
+  for (i in seq_len(niter)) {
+    sampled_list <- mapply(
+      FUN = function(pos) sample(ids[pos], length(pos), replace = TRUE),
+      pos = index_map,
+      SIMPLIFY = FALSE
+    )
+    vec <- character(length(ids))
+    vec[unlist(index_map, use.names = FALSE)] <-
+      unlist(sampled_list, use.names = FALSE)
+    out[i, ] <- vec
+  }
+  
+  return(out)
 }
 
 
